==> ejc-zdssupplierb-impl-3.0.0-20240725.072423-1-sources.jar: com/ejianc/business/zdssupplier/sub/bean/SupplierManagerHistoryEntity.java <==
package com.ejianc.business.zdssupplier.sub.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 分包供应商变更-项目经理
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supplier_sub_history_project_manager")
public class SupplierManagerHistoryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="history_id")
    private Long historyId; // 历史记录主键
    @TableField(value="change_bid")
    private Long changeBid; // 变更子表主键
    @TableField(value="change_id")
    private Long changeId; // 主表id
    @TableField(value="id_card_type")
    private Integer idCardType; // 证件类型 1:身份证,2:护照,3:港澳通行证,4:台胞证
    @TableField(value="id_card_id")
    private String idCardId; // 证件Id
    @TableField(value="project_manager_name")
    private String projectManagerName; // 项目经理姓名
    @TableField(value="project_manager_status")
    private Integer projectManagerStatus; // 项目经理状态 1:在职、2:离职
    @TableField(value="mobile_link_phone")
    private String mobileLinkPhone; // 移动电话
    @TableField(value="link_phone")
    private String linkPhone; // 固定电话
    @TableField(value="electronic_mail")
    private String electronicMail; // 电子邮件
    @TableField(value="address")
    private String address; // 通讯地址
    @TableField(value="synergy_account_status")
    private Integer synergyAccountStatus; // 协同账号 1:已生成，2：未生成； 默认2
    @TableField(value="enable_status")
    private Integer enableStatus; // 启用/停用 1:启用，2：停用； 默认1
    @TableField(value="source_id")
    private Long sourceId; // 来源主表id
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源子表id
    @TableField(value="tenant")
    private Long tenant; // 协同租户Id
    @TableField(value="coordination")
    private String coordination; // 是否已生成供方租户：0-否，1-是
    @TableField(value="third_source_id")
    private String thirdSourceId; // 第三方来源Id
    @TableField(value="sup_user_id")
    private Long supUserId; //  供方用户id

    public Long getHistoryId() {
        return historyId;
    }

    public void setHistoryId(Long historyId) {
        this.historyId = historyId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Integer getIdCardType() {
        return idCardType;
    }

    public void setIdCardType(Integer idCardType) {
        this.idCardType = idCardType;
    }
    public String getIdCardId() {
        return idCardId;
    }

    public void setIdCardId(String idCardId) {
        this.idCardId = idCardId;
    }
    public String getProjectManagerName() {
        return projectManagerName;
    }

    public void setProjectManagerName(String projectManagerName) {
        this.projectManagerName = projectManagerName;
    }
    public Integer getProjectManagerStatus() {
        return projectManagerStatus;
    }

    public void setProjectManagerStatus(Integer projectManagerStatus) {
        this.projectManagerStatus = projectManagerStatus;
    }
    public String getMobileLinkPhone() {
        return mobileLinkPhone;
    }

    public void setMobileLinkPhone(String mobileLinkPhone) {
        this.mobileLinkPhone = mobileLinkPhone;
    }
    public String getLinkPhone() {
        return linkPhone;
    }

    public void setLinkPhone(String linkPhone) {
        this.linkPhone = linkPhone;
    }
    public String getElectronicMail() {
        return electronicMail;
    }

    public void setElectronicMail(String electronicMail) {
        this.electronicMail = electronicMail;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public Integer getSynergyAccountStatus() {
        return synergyAccountStatus;
    }

    public void setSynergyAccountStatus(Integer synergyAccountStatus) {
        this.synergyAccountStatus = synergyAccountStatus;
    }
    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Long getTenant() {
        return tenant;
    }

    public void setTenant(Long tenant) {
        this.tenant = tenant;
    }
    public String getCoordination() {
        return coordination;
    }

    public void setCoordination(String coordination) {
        this.coordination = coordination;
    }
    public String getThirdSourceId() {
        return thirdSourceId;
    }

    public void setThirdSourceId(String thirdSourceId) {
        this.thirdSourceId = thirdSourceId;
    }
    public Long getSupUserId() {
        return supUserId;
    }

    public void setSupUserId(Long supUserId) {
        this.supUserId = supUserId;
    }
    
}

==> ejc-zdssupplierb-impl-3.0.0-20241017.014544-4-sources.jar: com/ejianc/business/zdssupplier/sub/bean/SupplierManagerHistoryEntity.java <==
package com.ejianc.business.zdssupplier.sub.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 分包供应商变更-项目经理
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supplier_sub_history_project_manager")
public class SupplierManagerHistoryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="history_id")
    private Long historyId; // 历史记录主键
    @TableField(value="change_bid")
    private Long changeBid; // 变更子表主键
    @TableField(value="change_id")
    private Long changeId; // 主表id
    @TableField(value="id_card_type")
    private Integer idCardType; // 证件类型 1:身份证,2:护照,3:港澳通行证,4:台胞证
    @TableField(value="id_card_id")
    private String idCardId; // 证件Id
    @TableField(value="project_manager_name")
    private String projectManagerName; // 项目经理姓名
    @TableField(value="project_manager_status")
    private Integer projectManagerStatus; // 项目经理状态 0正常、1禁用、2黑名单
    @TableField(value="mobile_link_phone")
    private String mobileLinkPhone; // 移动电话
    @TableField(value="link_phone")
    private String linkPhone; // 固定电话
    @TableField(value="electronic_mail")
    private String electronicMail; // 电子邮件
    @TableField(value="address")
    private String address; // 通讯地址
    @TableField(value="synergy_account_status")
    private Integer synergyAccountStatus; // 协同账号 1:已生成，2：未生成； 默认2
    @TableField(value="enable_status")
    private Integer enableStatus; // 启用/停用 1:启用，2：停用； 默认1
    @TableField(value="source_id")
    private Long sourceId; // 来源主表id
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源子表id
    @TableField(value="tenant")
    private Long tenant; // 协同租户Id
    @TableField(value="coordination")
    private String coordination; // 是否已生成供方租户：0-否，1-是
    @TableField(value="third_source_id")
    private String thirdSourceId; // 第三方来源Id
    @TableField(value="sup_user_id")
    private Long supUserId; //  供方用户id

    public Long getHistoryId() {
        return historyId;
    }

    public void setHistoryId(Long historyId) {
        this.historyId = historyId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Integer getIdCardType() {
        return idCardType;
    }

    public void setIdCardType(Integer idCardType) {
        this.idCardType = idCardType;
    }
    public String getIdCardId() {
        return idCardId;
    }

    public void setIdCardId(String idCardId) {
        this.idCardId = idCardId;
    }
    public String getProjectManagerName() {
        return projectManagerName;
    }

    public void setProjectManagerName(String projectManagerName) {
        this.projectManagerName = projectManagerName;
    }
    public Integer getProjectManagerStatus() {
        return projectManagerStatus;
    }

    public void setProjectManagerStatus(Integer projectManagerStatus) {
        this.projectManagerStatus = projectManagerStatus;
    }
    public String getMobileLinkPhone() {
        return mobileLinkPhone;
    }

    public void setMobileLinkPhone(String mobileLinkPhone) {
        this.mobileLinkPhone = mobileLinkPhone;
    }
    public String getLinkPhone() {
        return linkPhone;
    }

    public void setLinkPhone(String linkPhone) {
        this.linkPhone = linkPhone;
    }
    public String getElectronicMail() {
        return electronicMail;
    }

    public void setElectronicMail(String electronicMail) {
        this.electronicMail = electronicMail;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public Integer getSynergyAccountStatus() {
        return synergyAccountStatus;
    }

    public void setSynergyAccountStatus(Integer synergyAccountStatus) {
        this.synergyAccountStatus = synergyAccountStatus;
    }
    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Long getTenant() {
        return tenant;
    }

    public void setTenant(Long tenant) {
        this.tenant = tenant;
    }
    public String getCoordination() {
        return coordination;
    }

    public void setCoordination(String coordination) {
        this.coordination = coordination;
    }
    public String getThirdSourceId() {
        return thirdSourceId;
    }

    public void setThirdSourceId(String thirdSourceId) {
        this.thirdSourceId = thirdSourceId;
    }
    public Long getSupUserId() {
        return supUserId;
    }

    public void setSupUserId(Long supUserId) {
        this.supUserId = supUserId;
    }
    
}
